;-----   Application avec un PIC 16F88 : Gestion d 'un seuil de temprature ------

; Titre : gestion d 'un seuil de temprature
; Date : 08 Avril 2010
; Auteur : P.M
; PIC utilis : PIC 16 F 88
; Ce montage d'initiation  base de PIC 16F88 va mettre en oeuvre les comparateurs
; de tension analogiques intgrs au PIC 16F88. Le montage compare les deux seuils 
; de tension prdfinis  la tension issue d 'un capteur de temprature de type LM 335.
; Si le premier seuil est atteint on valide une sortie ( led jaune ), si la temprature
; continue d 'voluer et si le deuxime seuil est atteint on valide une deuxime sortie
; ( led rouge )


;------------   Directive d' assemblage pour PLAB   ---------------

	list	p=16f88
	#include p16f88.inc
   errorlevel -302
    __CONFIG  _CONFIG1, _CCP1_RB0&_LVP_OFF&_MCLR_ON&_PWRTE_ON&_WDT_OFF&_HS_OSC                      
    __CONFIG  _CONFIG2, _IESO_OFF & _FCMEN_OFF

;------------   Dfinition des constantes   ---------------

W      			     EQU     0x00        ; variable W = 0 
F	 		     	 EQU     0x01        ; variable F = 1
inter			     EQU     0x00	 ; inter = 0 ( broche RB0 )
					
;------------   Dfinition des registres temporaires   ---------------

retard1      EQU        0x20      ; le registre temporaire retard1 pour la temporisation
retard2      EQU        0x21      ; le registre temporaire retard2 pour la temporisation

;***************   Numero de version  ***************

	org h'2100'
	de "Gestion d 'un seuil de temprature ver 1.0 08/04/02 "

;***********************   Programme principal  *******************************

	ORG 0

; ------ Programme d' INITIALISATION -------

;------------   Init des ports A et B   ---------------


	BANKSEL TRISB 			; Selection Bank du registre TRISB
	MOVLW 0x01            	; on met 01 dans le registre W
	MOVWF TRISB           	; on met 01 dans le port B il est programm partiellement en sortie

	MOVLW 0x0f            	; on met 0F dans le registre W
	MOVWF TRISA           	; on met 0F dans le port A il est programm en partiellement en sortie

	BANKSEL CMCON 			; Selection Bank du registre CMCON
	MOVLW B'00110100'       ; on met 34 dans le registre W 
	MOVWF CMCON           	; on met 34 dans le registre CMCON ( fonction utilise : mode 4 )
							; configuration en 2 comparateurs indpendants
	BANKSEL CVRCON 			; Selection Bank du registre ANSEL
	MOVLW B'10000000'       ; on met 80 dans le registre W 
	MOVWF CVRCON 			; validation du mode comparateur


;********************* Attente de l 'appui sur l 'inter *****************

init 
	BANKSEL inter 		; Selection Bank du registre inter

	btfsc PORTB,inter	; interrupteur marche - arrt  appuy ? si oui on  
	        			;va  l ' tiquette debut
	goto debut
	GOTO init
debut

	BSF PORTB,1
	call tempo

	BCF PORTB,1
	call tempo

	movf CMCON,W
	andlw B'11000000'
	movwf PORTB
	
	goto init

;********************** Temporisation courte T1 *************************

tempo
	MOVLW 0xff               ; on met ff dans le registre W
	MOVWF retard1            ; on met W dans le registre retard1 
	MOVWF retard2            ; on met W dans le registre retard2 

attente

	DECFSZ retard1,F         ; on dcrmente retard1 et on saute la prochaine instruction si 
	GOTO  attente            ; le registre retard1 = 0 sinon retour  l 'tiquette 'attente'

	movlw 0xff		 ; on recharge retard1 avec 90
	movwf retard1

	DECFSZ retard2,F         ; on dcrmente retard2 et on saute la prochaine instruction si 
	GOTO  attente            ; le registre retard2 = 0 sinon retour  l 'tiquette 'attente'

	return

	end	 
